@@ -18,22 +18,17 @@ module ActsAsApi
   #  end
   #
   # The `:api_template` parameter is required so the responder knows which api template it should render.
-
   class Responder < ActionController::Responder
-    module Module
-      # Overrides the base implementation of display, replacing it with
-      # the render_for_api method whenever api_template is specified.
-      def display(resource, given_options={})
-        api_template = options[:api_template]
+    # Overrides the base implementation of display, replacing it with
+    # the render_for_api method whenever api_template is specified.
+    def display(resource, given_options = {})
+      api_template = options[:api_template]
 
-        if api_template.nil? || !resource.respond_to?(:as_api_response)
-          controller.render given_options.merge!(options).merge!(format => resource)
-        else
-          controller.render_for_api api_template, given_options.merge!(options).merge!(format => resource)
-        end
+      if api_template.nil? || !resource.respond_to?(:as_api_response)
+        controller.render given_options.merge!(options).merge!(format => resource)
+      else
+        controller.render_for_api api_template, given_options.merge!(options).merge!(format => resource)
       end
     end
-
-    include Module
   end
 end
