@@ -22,16 +22,13 @@ ActiveRecordDummy::Application.configure do
   # Only use best-standards-support built into browsers
   config.action_dispatch.best_standards_support = :builtin
 
-  # Raise exception on mass assignment protection for Active Record models
-  config.active_record.mass_assignment_sanitizer = :strict
-
-  # Log the query plan for queries taking more than this (works
-  # with SQLite, MySQL, and PostgreSQL)
-  config.active_record.auto_explain_threshold_in_seconds = 0.5
-
   # Do not compress assets
   config.assets.compress = false
 
+  config.eager_load = false
+
+  config.secret_key_base = 'helloworld123'
+
   # Expands the lines which load the assets
   config.assets.debug = true
 end
